// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

#include "Constants.h"
#include "RobotContainer.h"
#include "commands/Eject.h"
#include "commands/Gather.h"
#include "commands/Shoot.h"

#include <frc/PowerDistribution.h>
#include <frc/smartdashboard/SmartDashboard.h>
#include <frc/Joystick.h>
#include <frc2/command/button/JoystickButton.h>

RobotContainer::RobotContainer() :
    m_autonomous_command(m_chassis, m_shooter, m_gatherer) {
  // Initialize all of your commands and subsystems here
  m_chassis.SetDefaultCommand(DriveWithJoysticks(m_chassis, m_driver));

  frc::SmartDashboard::PutData("chassis", &m_chassis);
  frc::SmartDashboard::PutData("shooter", &m_shooter);

  // Configure the button bindings
  map_buttons();
}

void RobotContainer::map_buttons() {
  // Configure your button bindings here
  // Zero gyro
  frc2::JoystickButton(&m_driver, 8).WhenPressed(
    frc2::InstantCommand{[this] {
      m_chassis.zero_gyro(); }, {&m_chassis}});

  // Shooter speeds
  frc2::JoystickButton(&m_manip, 4).WhenPressed(
    frc2::InstantCommand{[this] {
      m_shooter.set(constants::shooter::HIGH); }});
  frc2::JoystickButton(&m_manip, 3).WhenPressed(
    frc2::InstantCommand{[this] {
      m_shooter.set(constants::shooter::MED); }});
  frc2::JoystickButton(&m_manip, 1).WhenPressed(
    frc2::InstantCommand{[this] {
      m_shooter.set(constants::shooter::LOW); }});
  frc2::JoystickButton(&m_manip, 2).WhenPressed(
    frc2::InstantCommand{[this] {
      m_shooter.set(0_rpm); }});

  // Gatherer
  frc2::JoystickButton(&m_driver, 6).WhileHeld(Gather(m_gatherer));
  frc2::JoystickButton(&m_driver, 4).WhileHeld(Eject(m_gatherer));

  // Shoot
  frc2::JoystickButton(&m_manip, 6).WhileHeld(Shoot(m_gatherer, m_shooter));
}

frc2::Command* RobotContainer::get_autonomous_command() {
  // An example command will be run in autonomous
  return &m_autonomous_command;
}
